

local major, minor, libTable = LibStub("LibBuilder-1.0"):GetLib()
if not libTable.canLoad then return end


local interface = libTable.interface
local debug = libTable.debug


interface.messageCache = {}
interface.tabsAvailable = false


---	Creates and returns a new Stream
--	@param	destinations	Optional; list of destinations to add to the Stream.
function interface:NewStream(...)
	local argCount = select("#", ...)
	local args = {...}
	
	local stream = libTable.classes.Stream:New()
	
	for i=1, argCount do
		local destination = self:NewDestination(args[i])
		stream:AddDestination(destination)
	end
	
	--debug("NewStream, returning", stream)
	
	return stream
end


---	Creates and returns a new Destination.
--	@param	value	Initial value for the Destination.
function interface:NewDestination(value)
	return libTable.classes.Destination:New(value)
end


---	Retrieves the file-path to the function that called this method.
--	EXPERIMENTAL! SUBJECT TO CHANGE
--	@return	path	Path to the caller, or nil if not found.
function interface:GetCallerPath()
	local stack = debugstack()
	local line = string.match(stack, "\n(.-)\n")

	--	TODO: if path gets truncated...
	local shortPath = string.match(line, "Interface\\AddOns\\(.-):")
	
	return shortPath
end


---	Prints a string in the format "running %s", where %s is the path to the caller's file.
--	EXPERIMENTAL! SUBJECT TO CHANGE
function interface:Trace()
	local stack = debugstack()
	local line = string.match(stack, "\n(.-)\n")

	--	TODO: if path gets truncated...
	local shortPath = string.match(line, "Interface\\AddOns\\(.-):")
	
	if shortPath then
		print("running", shortPath)
	else
		print(string.format("%s:Trace could not find the path to the caller."))
	end
end
